@@ -24,13 +24,9 @@
 #'
 #' @return a `SoilProfileCollection` for a successful query, a `try-error` if no site/pedon locations can be found or `NULL` for an empty `lab_layer` (within sites/pedons) result
 #' @export
-#'
+#' @examplesIf curl::has_internet()
 #' @examples
 #' \dontrun{
-#'
-#' if(requireNamespace("curl") &
-#'    curl::has_internet()) {
-#'
 #'   # fetch by ssa_key
 #'   res <- fetchLDM(8297, what = "ssa_key")
 #'
@@ -42,8 +38,6 @@
 #'   # fetch by area_code (SSA only)  
 #'   res <- fetchLDM("CA630", what = "area_code")
 #' }
-#'
-#' }
 #' @importFrom aqp `depths<-` `site<-`
 #' @importFrom data.table rbindlist
 fetchLDM <- function(x = NULL,
@@ -230,6 +224,7 @@ fetchLDM <- function(x = NULL,
       hzn <- aqp::horizonNames(hz)
       hzn <- hzn[hzn != idname(hz)]
       site(hz) <- sites[, !colnames(sites) %in% hzn]
+      hzdesgnname(hz) <- 'hzn_desgn'
 
       return(hz)
     } else {
