@@ -16,7 +16,10 @@ test_that("fetchSCAN() works", {
   
   # standard request
   expect_true(inherits(x, 'list'))
-
+  
+  # completely empty request for valid site
+  y <<- fetchSCAN(site.code = 2072, year = 1800)
+  
 })
 
 test_that("fetchSCAN() returns the right kind of data", {
@@ -34,5 +37,7 @@ test_that("fetchSCAN() returns the right kind of data", {
   expect_true(inherits(x$metadata, 'data.frame'))
   expect_true(inherits(x$STO, 'data.frame'))
   expect_true(ncol(x$STO) == 8)
-
+  
+  expect_true(inherits(y, 'list'))
+  expect_equal(nrow(y$metadata), 1)
 })
